==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/RouteIngressBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RouteIngressBuilder extends io.fabric8.openshift.api.model.RouteIngressFluentImpl<io.fabric8.openshift.api.model.RouteIngressBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.RouteIngress,io.fabric8.openshift.api.model.RouteIngressBuilder>{
  public RouteIngressBuilder() {
    this(false);
  }
  public RouteIngressBuilder(java.lang.Boolean validationEnabled) {
    this(new RouteIngress(), validationEnabled);
  }
  public RouteIngressBuilder(io.fabric8.openshift.api.model.RouteIngressFluent<?> fluent) {
    this(fluent, false);
  }
  public RouteIngressBuilder(io.fabric8.openshift.api.model.RouteIngressFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RouteIngress(), validationEnabled);
  }
  public RouteIngressBuilder(io.fabric8.openshift.api.model.RouteIngressFluent<?> fluent,io.fabric8.openshift.api.model.RouteIngress instance) {
    this(fluent, instance, false);
  }
  public RouteIngressBuilder(io.fabric8.openshift.api.model.RouteIngressFluent<?> fluent,io.fabric8.openshift.api.model.RouteIngress instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withHost(instance.getHost()); 
    fluent.withRouterCanonicalHostname(instance.getRouterCanonicalHostname()); 
    fluent.withRouterName(instance.getRouterName()); 
    fluent.withWildcardPolicy(instance.getWildcardPolicy()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RouteIngressBuilder(io.fabric8.openshift.api.model.RouteIngress instance) {
    this(instance,false);
  }
  public RouteIngressBuilder(io.fabric8.openshift.api.model.RouteIngress instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withHost(instance.getHost()); 
    this.withRouterCanonicalHostname(instance.getRouterCanonicalHostname()); 
    this.withRouterName(instance.getRouterName()); 
    this.withWildcardPolicy(instance.getWildcardPolicy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.RouteIngressFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.RouteIngress build() {
    RouteIngress buildable = new RouteIngress(fluent.getConditions(),fluent.getHost(),fluent.getRouterCanonicalHostname(),fluent.getRouterName(),fluent.getWildcardPolicy());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RouteIngressBuilder that = (RouteIngressBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.2.0-sources.jar: io/fabric8/openshift/api/model/RouteIngressBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RouteIngressBuilder extends RouteIngressFluentImpl<RouteIngressBuilder> implements VisitableBuilder<RouteIngress,RouteIngressBuilder>{
  public RouteIngressBuilder() {
    this(false);
  }
  public RouteIngressBuilder(Boolean validationEnabled) {
    this(new RouteIngress(), validationEnabled);
  }
  public RouteIngressBuilder(RouteIngressFluent<?> fluent) {
    this(fluent, false);
  }
  public RouteIngressBuilder(RouteIngressFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RouteIngress(), validationEnabled);
  }
  public RouteIngressBuilder(RouteIngressFluent<?> fluent,RouteIngress instance) {
    this(fluent, instance, false);
  }
  public RouteIngressBuilder(RouteIngressFluent<?> fluent,RouteIngress instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withHost(instance.getHost()); 
    fluent.withRouterCanonicalHostname(instance.getRouterCanonicalHostname()); 
    fluent.withRouterName(instance.getRouterName()); 
    fluent.withWildcardPolicy(instance.getWildcardPolicy()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RouteIngressBuilder(RouteIngress instance) {
    this(instance,false);
  }
  public RouteIngressBuilder(RouteIngress instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withHost(instance.getHost()); 
    this.withRouterCanonicalHostname(instance.getRouterCanonicalHostname()); 
    this.withRouterName(instance.getRouterName()); 
    this.withWildcardPolicy(instance.getWildcardPolicy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  RouteIngressFluent<?> fluent;
  Boolean validationEnabled;
  public RouteIngress build() {
    RouteIngress buildable = new RouteIngress(fluent.getConditions(),fluent.getHost(),fluent.getRouterCanonicalHostname(),fluent.getRouterName(),fluent.getWildcardPolicy());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
